pub struct Segment {
pub key: String,
pub included: Vec<String>,
pub excluded: Vec<String>,
pub unbounded: bool,
pub version: u64,
/* private fields */
}Expand description
Segment describes a group of contexts based on keys and/or matching rules.
Fields
key: StringThe unique key of the segment.
included: Vec<String>A list of context keys that are always matched by this segment.
excluded: Vec<String>A list of context keys that are never matched by this segment, unless the key is also in included.
unbounded: boolUnbounded is true if this is a segment whose included list is stored separately and is not limited in size. Currently, the server-side Rust SDK cannot access the context list for this kind of segment; it only works when flags are being evaluated within the LaunchDarkly service.
The name is historical: “unbounded segments” was an earlier name for the product feature that is currently known as “big segments”. If unbounded is true, this is a big segment.
version: u64An integer that is incremented by LaunchDarkly every time the configuration of the segment is changed.
Implementations