pub trait Store {
// Required methods
fn flag(&self, flag_key: &str) -> Option<Flag>;
fn segment(&self, segment_key: &str) -> Option<Segment>;
}Expand description
Store is an interface for a data store that holds feature flags and related data received by the SDK.
Ordinarily, the only implementations of this interface are the default in-memory implementation, which holds references to actual SDK data model objects.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".